@@ -15,7 +15,6 @@ import itertools
 from collections import namedtuple
 import json
 import os
-import os.path
 import shutil
 from .py2help import _inttypes, _strtypes, imap, xrange
 
@@ -81,7 +80,7 @@ class cols(object):
         """Return the named column and remove it."""
         pos = self.names.index(name)
         name = self.names.pop(pos)
-        col = self._cols[name]
+        col = self._cols.pop(name)
         self.update_meta()
         return col
 
@@ -99,16 +98,13 @@ class cols(object):
 
 
 class ctable(object):
-    """
-    ctable(cols, names=None, **kwargs)
-
-    This class represents a compressed, column-wise, in-memory table.
+    """ This class represents a compressed, column-wise, in-memory table.
 
     Create a new ctable from `cols` with optional `names`.
 
     Parameters
     ----------
-    columns : tuple or list of column objects
+    cols : tuple or list of column objects
         The list of column data to build the ctable object.  This can also be
         a pure NumPy structured array.  A list of lists or tuples is valid
         too, as long as they can be converted into carray objects.
@@ -147,7 +143,13 @@ class ctable(object):
     def dtype(self):
         "The data type of this object (numpy dtype)."
         names, cols = self.names, self.cols
-        l = [(name, cols[name].dtype) for name in names]
+        l = []
+        for name in names:
+            col = cols[name]
+            # Need to account for multidimensional columns
+            t = (name, col.dtype) if col.ndim == 1 else \
+                (name, (col.dtype, col.shape[1:]))
+            l.append(t)
         return np.dtype(l)
 
     @property
@@ -180,6 +182,10 @@ class ctable(object):
         # Important optional params
         self._cparams = kwargs.get('cparams', bcolz.cparams())
         self.rootdir = kwargs.get('rootdir', None)
+        if self.rootdir is not None:
+            self.auto_flush = kwargs.get('auto_flush', True)
+        else:
+            self.auto_flush = False
         "The directory where this object is saved."
         if self.rootdir is None and columns is None:
             raise ValueError(
@@ -291,8 +297,13 @@ class ctable(object):
 
         self.len = clen
 
+        if self.auto_flush:
+            self.flush()
+
     def open_ctable(self):
         """Open an existing ctable on-disk."""
+        if self.mode == 'r' and not os.path.exists(self.rootdir):
+            raise KeyError("Disk-based ctable opened with `r`ead mode yet `rootdir` does not exist")
 
         # Open the ctable by reading the metadata
         self.cols.read_meta_and_open()
@@ -314,10 +325,7 @@ class ctable(object):
         os.mkdir(rootdir)
 
     def append(self, cols):
-        """
-        append(cols)
-
-        Append `cols` to this ctable.
+        """Append `cols` to this ctable.
 
         Parameters
         ----------
@@ -363,18 +371,18 @@ class ctable(object):
             if sclist and not hasattr(column, '__len__'):
                 clen2 = 1
             else:
-                clen2 = len(column)
+                clen2 = 1 if isinstance(column, _strtypes) else len(column)
             if clen >= 0 and clen != clen2:
                 raise ValueError(
                     "all cols in `cols` must have the same length")
             clen = clen2
         self.len += clen
 
-    def trim(self, nitems):
-        """
-        trim(nitems)
+        if self.auto_flush:
+            self.flush()
 
-        Remove the trailing `nitems` from this instance.
+    def trim(self, nitems):
+        """Remove the trailing `nitems` from this instance.
 
         Parameters
         ----------
@@ -388,10 +396,7 @@ class ctable(object):
         self.len -= nitems
 
     def resize(self, nitems):
-        """
-        resize(nitems)
-
-        Resize the instance to have `nitems`.
+        """Resize the instance to have `nitems`.
 
         Parameters
         ----------
@@ -406,11 +411,8 @@ class ctable(object):
             self.cols[name].resize(nitems)
         self.len = nitems
 
-    def addcol(self, newcol, name=None, pos=None, **kwargs):
-        """
-        addcol(newcol, name=None, pos=None, **kwargs)
-
-        Add a new `newcol` object as column.
+    def addcol(self, newcol, name=None, pos=None, move=False, **kwargs):
+        """Add a new `newcol` object as column.
 
         Parameters
         ----------
@@ -424,6 +426,10 @@ class ctable(object):
         pos : int, optional
             The column position.  If not passed, it will be appended
             at the end.
+        move: boolean, optional
+            If the new column is an existing, disk-based carray should it
+            a) copy the data directory (False) or
+            b) move the data directory (True)
         kwargs : list of parameters or dictionary
             Any parameter supported by the carray constructor.
 
@@ -456,13 +462,24 @@ class ctable(object):
         if len(newcol) != self.len:
             raise ValueError("`newcol` must have the same length than ctable")
 
-        if isinstance(newcol, np.ndarray):
-            if 'cparams' not in kwargs:
-                kwargs['cparams'] = self.cparams
+        if self.rootdir is not None:
+            col_rootdir = os.path.join(self.rootdir, name)
+            kwargs.setdefault('rootdir', col_rootdir)
+
+        kwargs.setdefault('cparams', self.cparams)
+
+        if isinstance(newcol, bcolz.carray) and \
+                        self.rootdir is not None and \
+                        newcol.rootdir is not None:
+            # a special case, where you have a disk-based carray is inserted in a disk-based ctable
+            if move:  # move the the carray
+                shutil.move(newcol.rootdir, col_rootdir)
+                newcol.rootdir = col_rootdir
+            else:  # copy the the carray
+                newcol = newcol.copy(rootdir=col_rootdir)
+        elif isinstance(newcol, (np.ndarray, bcolz.carray)):
             newcol = bcolz.carray(newcol, **kwargs)
         elif type(newcol) in (list, tuple):
-            if 'cparams' not in kwargs:
-                kwargs['cparams'] = self.cparams
             newcol = bcolz.carray(newcol, **kwargs)
         elif type(newcol) != bcolz.carray:
             raise ValueError(
@@ -473,11 +490,11 @@ class ctable(object):
         # Update _arr1
         self._arr1 = np.empty(shape=(1,), dtype=self.dtype)
 
-    def delcol(self, name=None, pos=None):
-        """
-        delcol(name=None, pos=None)
+        if self.auto_flush:
+            self.flush()
 
-        Remove the column named `name` or in position `pos`.
+    def delcol(self, name=None, pos=None, keep=False):
+        """Remove the column named `name` or in position `pos`.
 
         Parameters
         ----------
@@ -485,6 +502,8 @@ class ctable(object):
             The name of the column to remove.
         pos: int, optional
             The position of the column to remove.
+        keep: boolean
+            For disk-backed columns: keep the data on disk?
 
         Notes
         -----
@@ -516,15 +535,19 @@ class ctable(object):
             name = self.names[pos]
 
         # Remove the column
-        self.cols.pop(name)
+        col = self.cols.pop(name)
+
+        if not keep:
+            col.purge()
+
         # Update _arr1
         self._arr1 = np.empty(shape=(1,), dtype=self.dtype)
 
-    def copy(self, **kwargs):
-        """
-        copy(**kwargs)
+        if self.auto_flush:
+            self.flush()
 
-        Return a copy of this ctable.
+    def copy(self, **kwargs):
+        """Return a copy of this ctable.
 
         Parameters
         ----------
@@ -558,10 +581,7 @@ class ctable(object):
 
     @staticmethod
     def fromdataframe(df, **kwargs):
-        """
-        fromdataframe(df, **kwargs)
-
-        Return a ctable object out of a pandas dataframe.
+        """Return a ctable object out of a pandas dataframe.
 
         Parameters
         ----------
@@ -575,8 +595,8 @@ class ctable(object):
         out : ctable object
             A ctable filled with values from `df`.
 
-        Note
-        ----
+        Notes
+        -----
         The 'object' dtype will be converted into a 'S'tring type, if possible.
         This allows for much better storage savings in bcolz.
 
@@ -634,10 +654,7 @@ class ctable(object):
 
     @staticmethod
     def fromhdf5(filepath, nodepath='/ctable', **kwargs):
-        """
-        fromhdf5(filepath, nodepath='/ctable', **kwargs)
-
-        Return a ctable object out of a compound HDF5 dataset (PyTables Table).
+        """Return a ctable object out of a compound HDF5 dataset (PyTables Table).
 
         Parameters
         ----------
@@ -692,10 +709,7 @@ class ctable(object):
         return ct
 
     def todataframe(self, columns=None, orient='columns'):
-        """
-        todataframe(columns=None, orient='columns')
-
-        Return a pandas dataframe out of this object.
+        """Return a pandas dataframe out of this object.
 
         Parameters
         ----------
@@ -730,11 +744,7 @@ class ctable(object):
 
     def tohdf5(self, filepath, nodepath='/ctable', mode='w',
                cparams=None, cname=None):
-        """
-        tohdf5(filepath, nodepath='/ctable', mode='w',
-               cparams=None, cname=None)
-
-        Write this object into an HDF5 file.
+        """Write this object into an HDF5 file.
 
         Parameters
         ----------
@@ -787,10 +797,7 @@ class ctable(object):
         return self.cbytes
 
     def where(self, expression, outcols=None, limit=None, skip=0):
-        """
-        where(expression, outcols=None, limit=None, skip=0)
-
-        Iterate over rows where `expression` is true.
+        """Iterate over rows where `expression` is true.
 
         Parameters
         ----------
@@ -857,9 +864,7 @@ class ctable(object):
 
     def whereblocks(self, expression, blen=None, outfields=None, limit=None,
                     skip=0):
-        """whereblocks(expression, blen=None, outfields=None, limit=None, skip=0)
-
-        Iterate over the rows that fullfill the `expression` condition on
+        """Iterate over the rows that fullfill the `expression` condition on
         this ctable, in blocks of size `blen`.
 
         Parameters
@@ -924,10 +929,7 @@ class ctable(object):
 
     def iter(self, start=0, stop=None, step=1, outcols=None,
              limit=None, skip=0):
-        """
-        iter(start=0, stop=None, step=1, outcols=None, limit=None, skip=0)
-
-        Iterator with `start`, `stop` and `step` bounds.
+        """Iterator with `start`, `stop` and `step` bounds.
 
         Parameters
         ----------
@@ -1018,12 +1020,10 @@ class ctable(object):
         return result
 
     def __getitem__(self, key):
-        """
-        x.__getitem__(key) <==> x[key]
+        """Returns values based on `key`.
 
-        Returns values based on `key`.  All the functionality of
-        ``ndarray.__getitem__()`` is supported (including fancy
-        indexing), plus a special support for expressions:
+        All the functionality of ``ndarray.__getitem__()`` is supported
+        (including fancy indexing), plus a special support for expressions:
 
         Parameters
         ----------
@@ -1113,12 +1113,10 @@ class ctable(object):
         return ra
 
     def __setitem__(self, key, value):
-        """
-        x.__setitem__(key, value) <==> x[key] = value
+        """Sets values based on `key`.
 
-        Sets values based on `key`.  All the functionality of
-        ``ndarray.__setitem__()`` is supported (including fancy
-        indexing), plus a special support for expressions:
+        All the functionality of ``ndarray.__setitem__()`` is supported
+        (including fancy indexing), plus a special support for expressions:
 
         Parameters
         ----------
@@ -1158,10 +1156,7 @@ class ctable(object):
         return
 
     def eval(self, expression, **kwargs):
-        """
-        eval(expression, **kwargs)
-
-        Evaluate the `expression` on columns and return the result.
+        """Evaluate the `expression` on columns and return the result.
 
         Parameters
         ----------
@@ -1215,10 +1210,7 @@ class ctable(object):
             self.cols[name].free_cachemem()
 
     def _get_stats(self):
-        """
-        _get_stats()
-
-        Get some stats (nbytes, cbytes and ratio) about this object.
+        """Get some stats (nbytes, cbytes and ratio) about this object.
 
         Returns
         -------
