@@ -9,8 +9,11 @@
 
 from __future__ import absolute_import
 
+import os
 import sys
 import struct
+import shutil
+import textwrap
 
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
@@ -2091,6 +2094,58 @@ class reprTest(TestCase):
         for el in x:
             self.assertTrue(el in result)
 
+class PurgeDiskArrayTest(MayBeDiskTest, TestCase):
+    disk = True
+
+    def test_purge(self):
+        b = bcolz.arange(1e2, rootdir=self.rootdir)
+        b.purge()
+        self.assertFalse(os.path.isdir(self.rootdir))
+
+    def test_purge_fails_for_missing_directory(self):
+        b = bcolz.arange(1e2, rootdir=self.rootdir)
+        shutil.rmtree(self.rootdir)
+        # OSError is fairly un-specific, but better than nothing
+        self.assertRaises(OSError, b.purge)
+
+class PurgeMemoryArrayTest(MayBeDiskTest, TestCase):
+    disk = False
+
+    def test_purge(self):
+        b = bcolz.arange(1e2, rootdir=self.rootdir)
+        # this should work and should be a noop
+        b.purge()
+
+class reprDiskTest(MayBeDiskTest,TestCase):
+    disk = True
+
+    def _create_expected(self, mode):
+        expected = textwrap.dedent("""
+                   carray((0,), float64)
+                     nbytes: 0; cbytes: 16.00 KB; ratio: 0.00
+                     cparams := cparams(clevel=5, shuffle=True, cname='blosclz')
+                     rootdir := '%s'
+                     mode    := '%s'
+                   []
+                   """ % (self.rootdir, mode)).strip()
+        return expected
+
+
+    def test_repr_disk_array_write(self):
+        x = carray([], rootdir=self.rootdir, mode='w')
+        expected = self._create_expected('w')
+        self.assertEqual(expected, repr(x))
+
+    def test_repr_disk_array_read(self):
+        x = carray([], rootdir=self.rootdir, mode='r')
+        expected = self._create_expected('r')
+        self.assertEqual(expected, repr(x))
+
+    def test_repr_disk_array_append(self):
+        x = carray([], rootdir=self.rootdir, mode='w')
+        y = carray(rootdir=self.rootdir)
+        expected = self._create_expected('a')
+        self.assertEqual(expected, repr(y))
 
 
 if __name__ == '__main__':
