@@ -14,13 +14,12 @@ import tempfile
 
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
-from bcolz.tests.common import (
-    MayBeDiskTest, TestCase, unittest, skipUnless)
+from bcolz.tests.common import MayBeDiskTest, TestCase, unittest, skipUnless
 import bcolz
 from bcolz.py2help import xrange, PY2
 import pickle
 import os
-import shutil
+from mock import Mock
 
 
 class createTest(MayBeDiskTest):
@@ -380,6 +379,71 @@ class add_del_colMemoryTest(add_del_colTest, TestCase):
 class add_del_colDiskTest(add_del_colTest, TestCase):
     disk = True
 
+    def test_add_new_column_ondisk(self):
+        """Testing adding a new column properly creates a new disk array (list
+        flavor)
+        """
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        c = np.fromiter(("s%d" % i for i in xrange(N)), dtype='S2')
+        t.addcol(c.tolist(), 'f2')
+        ra = np.fromiter(((i, i * 2., "s%d" % i) for i in xrange(N)),
+                         dtype='i4,f8,S2')
+        newpath = os.path.join(self.rootdir, 'f2')
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+        assert_array_equal(bcolz.carray(rootdir=newpath)[:], ra['f2'])
+
+    def test_del_new_column_ondisk(self):
+        """Testing delcol removes data on disk.
+        """
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        c = np.fromiter(("s%d" % i for i in xrange(N)), dtype='S2')
+        t.addcol(c.tolist(), 'f2')
+        ra = np.fromiter(((i, i * 2., "s%d" % i) for i in xrange(N)),
+                         dtype='i4,f8,S2')
+        newpath = os.path.join(self.rootdir, 'f2')
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+        assert_array_equal(bcolz.carray(rootdir=newpath)[:], ra['f2'])
+        t.delcol('f2')
+        self.assertFalse(os.path.exists(newpath))
+
+    def test_del_new_column_ondisk(self):
+        """Testing delcol with keep keeps the data.
+        """
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        c = np.fromiter(("s%d" % i for i in xrange(N)), dtype='S2')
+        t.addcol(c.tolist(), 'f2')
+        ra = np.fromiter(((i, i * 2., "s%d" % i) for i in xrange(N)),
+                         dtype='i4,f8,S2')
+        newpath = os.path.join(self.rootdir, 'f2')
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+        assert_array_equal(bcolz.carray(rootdir=newpath)[:], ra['f2'])
+        t.delcol('f2', keep=True)
+        self.assertTrue(os.path.exists(newpath))
+
+    def test_add_new_column_ondisk_other_carray_rootdir(self):
+        """Testing addcol with different rootdir.
+        """
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        c = np.fromiter(("s%d" % i for i in xrange(N)), dtype='S2')
+        temp_dir = os.path.join(tempfile.mkdtemp('bcolz-'), 'c')
+        c = bcolz.carray(c, rootdir=temp_dir)
+        t.addcol(c, 'f2')
+        ra = np.fromiter(((i, i * 2., "s%d" % i) for i in xrange(N)),
+                         dtype='i4,f8,S2')
+        newpath = os.path.join(self.rootdir, 'f2')
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+        assert_array_equal(bcolz.carray(rootdir=newpath)[:], ra['f2'])
+        self.assertEqual(temp_dir, c.rootdir)
+        self.assertEqual(newpath, t['f2'].rootdir)
+
 
 class getitemTest(MayBeDiskTest):
 
@@ -443,6 +507,26 @@ class getitemTest(MayBeDiskTest):
         assert_array_equal(t[colnames][:], ra2,
                            "ctable values are not correct")
 
+    def test05a(self):
+        """Testing __getitem__ with total slice"""
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        assert_array_equal(t[:], ra[:],
+                           "ctable values are not correct")
+
+    def test05b(self):
+        """Testing __getitem__ with total slice for table including a
+        multidimensional column"""
+        N = 10
+        # N.B., col1 is 2D
+        ra = np.fromiter(((i, (i * 2., i * 4.))
+                          for i in xrange(N)),
+                          dtype=[('col0', 'i4'), ('col1', ('f8', 2))])
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        assert_array_equal(t[:], ra[:],
+                           "ctable values are not correct")
+
 
 class getitemMemoryTest(getitemTest, TestCase):
     disk = False
@@ -1890,6 +1974,123 @@ class pickleTest(MayBeDiskTest, TestCase):
         self.assertEquals(type(b2), type(b))
 
 
+class FlushDiskTest(MayBeDiskTest, TestCase):
+    disk = True
+
+    def test_01(self):
+        '''Testing autoflush new disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (chunklen=30 and N=100)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+
+        t = bcolz.open(rootdir=self.rootdir)
+        assert_array_equal(a, t[:], 'not working correctly')
+
+    def test_02(self):
+        '''Testing autoflush when appending data to a disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+
+        y = np.array([(-1.0,-2.0)], dtype=[('f0', 'i4'), ('f1', 'f8')])
+        t.append(y)
+
+        t = bcolz.open(rootdir=self.rootdir)
+        assert_array_equal(np.append(a, y, 0), t[:], 'not working correctly')
+
+    def test_03(self):
+        '''Testing autoflush adding column data to a disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+
+        y = np.fromiter(((i * 3) for i in xrange(N)), dtype='i8')
+        t.addcol(y)
+
+        t = bcolz.open(rootdir=self.rootdir)
+        assert_array_equal(a['f0'], t['f0'], 'not working correctly')
+        assert_array_equal(a['f1'], t['f1'], 'not working correctly')
+        assert_array_equal(y, t['f2'], 'not working correctly')
+
+    def test_04(self):
+        '''Testing autoflush deleting a column to a disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+
+        y = np.fromiter(((i * 3) for i in xrange(N)), dtype='i8')
+        t.delcol('f1')
+
+        t = bcolz.open(rootdir=self.rootdir)
+        assert_array_equal(a['f0'], t['f0'], 'not working correctly')
+        self.assertTrue('f1' not in t.cols.names)
+
+    def test_05(self):
+        '''Testing flush call on a new disk-based ctable'''
+        tmp_var = bcolz.ctable.flush
+        bcolz.ctable.flush = Mock()
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (chunklen=30 and N=100)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+
+        t.flush.assert_called_with()
+        bcolz.ctable.flush = tmp_var
+
+    def test_06(self):
+        '''Testing flush call when appending data disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+        t.flush = Mock()
+
+        y = np.array([(-1.0,-2.0)], dtype=[('f0', 'i4'), ('f1', 'f8')])
+        t.append(y)
+
+        t.flush.assert_called_with()
+
+    def test_07(self):
+        '''Testing flush call after adding column data to a disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+        t.flush = Mock()
+
+        y = np.fromiter(((i * 3) for i in xrange(N)), dtype='i8')
+        t.addcol(y)
+
+        t.flush.assert_called_with()
+
+    def test_08(self):
+        '''Testing flush call after deleting a column to a disk-based ctable'''
+        N = 100
+        a = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        # force ctable with leftovers (N is not a multiple of chunklen)
+        t = bcolz.ctable(a, chunklen=30, rootdir=self.rootdir)
+        t.flush = Mock()
+
+        y = np.fromiter(((i * 3) for i in xrange(N)), dtype='i8')
+        t.delcol('f1')
+
+        t.flush.assert_called_with()
+
+    def test_strings(self):
+        """Testing that we can add fixed length strings to a ctable"""
+        dtype = np.dtype([("a", "|S5"),
+                          ("b", np.uint8),
+                          ("c", np.int32),
+                          ("d", np.float32)])
+        t = bcolz.ctable(np.empty(0, dtype=dtype), mode="w")
+        t.append(("aaaaa", 23, 34567, 1.2355))
+        self.assertTrue(len(t) == 1)
+        self.assertTrue(t["a"][0] == b"aaaaa", t["a"][0])
+
 if __name__ == '__main__':
     unittest.main(verbosity=2)
 
