@@ -12,19 +12,22 @@
 from __future__ import absolute_import
 
 import sys
-import os, os.path
+import os
+import os.path
 import glob
 import itertools as it
 import numpy as np
 import bcolz
+from bcolz.ctable import ROOTDIRS
 from .py2help import xrange, _inttypes
 
 
-
 def print_versions():
     """Print all the versions of packages that bcolz relies on."""
     print("-=" * 38)
     print("bcolz version:     %s" % bcolz.__version__)
+    if bcolz.git_description:
+        print("bcolz git info:    %s" % bcolz.git_description)
     print("NumPy version:     %s" % np.__version__)
     tinfo = bcolz.blosc_version()
     blosc_cnames = bcolz.blosc_compressor_list()
@@ -34,7 +37,7 @@ def print_versions():
         print("Numexpr version:   %s" % bcolz.numexpr.__version__)
     else:
         print("Numexpr version:   not available "
-              "(version >= %s not detected)" %  bcolz.min_numexpr_version)
+              "(version >= %s not detected)" % bcolz.min_numexpr_version)
     print("Python version:    %s" % sys.version)
     if os.name == "posix":
         (sysname, nodename, release, version, machine) = os.uname()
@@ -58,14 +61,15 @@ def detect_number_of_cores():
             ncpus = os.sysconf("SC_NPROCESSORS_ONLN")
             if isinstance(ncpus, int) and ncpus > 0:
                 return ncpus
-        else: # OSX:
+        else:  # OSX:
             return int(os.popen2("sysctl -n hw.ncpu")[1].read())
     # Windows:
     if "NUMBER_OF_PROCESSORS" in os.environ:
-        ncpus = int(os.environ["NUMBER_OF_PROCESSORS"]);
+        ncpus = int(os.environ["NUMBER_OF_PROCESSORS"])
         if ncpus > 0:
             return ncpus
-    return 1 # Default
+    return 1  # Default
+
 
 def set_nthreads(nthreads):
     """
@@ -96,6 +100,7 @@ def set_nthreads(nthreads):
         bcolz.numexpr.set_num_threads(nthreads)
     return nthreads_old
 
+
 def open(rootdir, mode='a'):
     """
     open(rootdir, mode='a')
@@ -116,21 +121,16 @@ def open(rootdir, mode='a'):
 
     Returns
     -------
-    out : a carray/ctable object or None (if not objects are found)
+    out : a carray/ctable object or IOError (if not objects are found)
 
     """
     # First try with a carray
-    obj = None
-    try:
-        obj = bcolz.carray(rootdir=rootdir, mode=mode)
-    except IOError:
-        # Not a carray.  Now with a ctable
-        try:
-            obj = bcolz.ctable(rootdir=rootdir, mode=mode)
-        except IOError:
-            # Not a ctable
-            pass
-    return obj
+    rootsfile = os.path.join(rootdir, ROOTDIRS)
+    if os.path.exists(rootsfile):
+        return bcolz.ctable(rootdir=rootdir, mode=mode)
+    else:
+        return bcolz.carray(rootdir=rootdir, mode=mode)
+
 
 def fromiter(iterable, dtype, count, **kwargs):
     """
@@ -227,6 +227,7 @@ def fromiter(iterable, dtype, count, **kwargs):
     obj.flush()
     return obj
 
+
 def fill(shape, dflt=None, dtype=np.float, **kwargs):
     """
     fill(shape, dtype=float, dflt=None, **kwargs)
@@ -287,6 +288,7 @@ def fill(shape, dflt=None, dtype=np.float, **kwargs):
     obj.flush()
     return obj
 
+
 def zeros(shape, dtype=np.float, **kwargs):
     """
     zeros(shape, dtype=float, **kwargs)
@@ -316,6 +318,7 @@ def zeros(shape, dtype=np.float, **kwargs):
     dtype = np.dtype(dtype)
     return fill(shape=shape, dflt=np.zeros((), dtype), dtype=dtype, **kwargs)
 
+
 def ones(shape, dtype=np.float, **kwargs):
     """
     ones(shape, dtype=float, **kwargs)
@@ -345,6 +348,7 @@ def ones(shape, dtype=np.float, **kwargs):
     dtype = np.dtype(dtype)
     return fill(shape=shape, dflt=np.ones((), dtype), dtype=dtype, **kwargs)
 
+
 def arange(start=None, stop=None, step=None, dtype=None, **kwargs):
     """
     arange([start,] stop[, step,], dtype=None, **kwargs)
@@ -427,6 +431,7 @@ def arange(start=None, stop=None, step=None, dtype=None, **kwargs):
     obj.flush()
     return obj
 
+
 def iterblocks(cobj, blen=None, start=0, stop=None):
     """iterblocks(blen=None, start=0, stop=None)
 
@@ -448,7 +453,7 @@ def iterblocks(cobj, blen=None, start=0, stop=None):
     Returns
     -------
     out : iterable
-        This iterable returns buffers as NumPy arays of homogeneous or
+        This iterable returns buffers as NumPy arrays of homogeneous or
         structured types, depending on whether `cobj` is a carray or a
         ctable object.
 
@@ -616,9 +621,12 @@ class cparams(object):
         """
         clevel, shuffle, cname = cparams._checkparams(clevel, shuffle, cname)
         dflts = bcolz.defaults.cparams
-        if clevel is not None: dflts['clevel'] = clevel
-        if shuffle is not None: dflts['shuffle'] = shuffle
-        if cname is not None: dflts['cname'] = cname
+        if clevel is not None:
+            dflts['clevel'] = clevel
+        if shuffle is not None:
+            dflts['shuffle'] = shuffle
+        if cname is not None:
+            dflts['cname'] = cname
 
     def __init__(self, clevel=None, shuffle=None, cname=None):
         clevel, shuffle, cname = cparams._checkparams(clevel, shuffle, cname)
@@ -635,10 +643,8 @@ class cparams(object):
         return '%s(%s)' % (self.__class__.__name__, ', '.join(args))
 
 
-
-
-## Local Variables:
-## mode: python
-## tab-width: 4
-## fill-column: 78
-## End:
+# Local Variables:
+# mode: python
+# tab-width: 4
+# fill-column: 78
+# End:
